@@ -20,7 +20,7 @@ class Router():
                             route = route.copy()
                             # Rule
                             mask = route['options'].pop('rulemask', None) or '/{view}/{rule}'
-                            url = cls.endpoint if cls.url is None else cls.url
+                            url = cls.endpoint if not hasattr(cls, 'url') else cls.url
                             rule = mask.format(view=url.strip('/'), rule=route['rule'].lstrip('/'))
                             # Endpoint
                             mask = route.pop('endpoint', None) or '{view}:{func}'
