@@ -1,8 +1,43 @@
-from flask import Flask
+from pprint import pprint
+from flask import Flask, Blueprint
 
 from flask.ext.routes.router import Router, route
 
 
+def test_blueprints():
+    app = Flask(__name__)
+    bp = Blueprint('bp', __name__, url_prefix='/xxx')
+
+    app_router = Router(app)
+    bp_router = Router(bp)
+
+    class PageView:
+        endpoint = 'pages'
+
+        @route('/index')
+        def index(self):
+            pass
+
+    class UserView:
+        endpoint = 'users'
+
+        @route('/index')
+        def index(self):
+            pass
+
+    app_router.route(PageView)
+    bp_router.route(UserView)
+    app.register_blueprint(bp)
+
+    rules = app.url_map._rules_by_endpoint # endpoint -> [Rule()]
+
+    assert len(rules.keys()) == 3 # 2 + 1 (default static)
+    assert 'pages:index' in rules.keys()
+    assert 'bp.users:index' in rules.keys()
+    assert str(rules['pages:index'][0]) == '/pages/index'
+    assert str(rules['bp.users:index'][0]) == '/xxx/users/index'
+
+
 def test_endpoint_mask():
     app = Flask(__name__)
     router = Router(app)
@@ -15,8 +50,7 @@ def test_endpoint_mask():
         def detail_by_path(self, path):
             pass
 
-    for view in [PageView]:
-        router.route(view)
+    router.route(PageView)
 
     rules = app.url_map._rules_by_endpoint # endpoint -> [Rule()]
     assert len(rules.keys()) == 2 # 1 + 1 (default static)
@@ -29,15 +63,14 @@ def test_url_mask():
     router = Router(app)
 
     class PageView:
-        # endpoint = 'pages'
+        endpoint = 'pages'
         url = '/pages'
 
         @route('/', rulemask='/{rule}')
         def index(self, path):
             pass
 
-    for view in [PageView]:
-        router.route(view)
+    router.route(PageView)
 
     rules = app.url_map._rules_by_endpoint # endpoint -> [Rule()]
     assert len(rules.keys()) == 2 # 1 + 1 (default static)
@@ -57,8 +90,7 @@ def test_slash_noise():
         def index(self, path):
             pass
 
-    for view in [PageView]:
-        router.route(view)
+    router.route(PageView)
 
     rules = app.url_map._rules_by_endpoint # endpoint -> [Rule()]
     assert len(rules.keys()) == 2 # 1 + 1 (default static)
@@ -127,8 +159,7 @@ def test_multiple_rules():
         router.route(view)
 
     rules = app.url_map._rules_by_endpoint # endpoint -> [Rule()]
-    from pprint import pprint
-    pprint(rules)
+
     assert len(rules.keys()) == 7 # 6 + 1 (default static)
     assert 'pages:index' in rules.keys()
     assert 'pages:index_json' in rules.keys()
